@@ -9,7 +9,7 @@ import numpy as np
 import pandas as pd
 from typing import Union
 from .network import MultiNet
-from .utility_lib import generate_absolute_path, update_filename
+from .utility_lib import generate_absolute_path, update_filename, path2linux
 from .func_lib import (
     extract_coordinates_by_network_mode,
     extract_coordinates_by_node_types,
@@ -27,6 +27,7 @@ from matplotlib.lines import Line2D
 import matplotlib.pyplot as plt
 from matplotlib.collections import LineCollection
 from matplotlib.collections import PolyCollection
+import os
 
 
 def show_network_by_modes(
@@ -39,7 +40,7 @@ def show_network_by_modes(
     Parameters
     ----------
     mnet : MultiNet object
-    modes : tuple, optional
+    modes :list, optional
             network mode, valid to ('all', 'auto', 'bike', 'walk', 'railway'),Defaults to ('all').
     fig_obj : figure object (plt) ,optional
               if not None, will continue to draw elements on the existing figure object. Defaults to None
@@ -94,8 +95,9 @@ def show_network_by_modes(
     plt.tight_layout()
 
     if isSave2png:
-        path_figure = update_filename(generate_absolute_path(file_name="network_by_mode.png"))
-        plt.savefig(path_figure)
+        path_figure = update_filename(generate_absolute_path(file_name="network_by_mode.png",
+                                                             folder_name=path2linux(os.path.join(os.getcwd(), "p4g_fig_results"))))
+        plt.savefig(path_figure,dpi=mnet.style.dpi)
         print(f"Successfully save figure to {path_figure}")
 
     return plt
@@ -177,12 +179,14 @@ def show_network_by_node_types(
     plt.tight_layout()
 
     if isSave2png:
-        path_figure = update_filename(generate_absolute_path(file_name="network_by_node_type.png"))
-        plt.savefig(path_figure)
+        path_figure = update_filename(generate_absolute_path(file_name="network_by_node_type.png",
+                                                             folder_name=path2linux(os.path.join(os.getcwd(), "p4g_fig_results"))))
+        plt.savefig(path_figure,dpi=mnet.style.dpi)
         print(f"Successfully save figure to {path_figure}")
 
     return plt
 
+
 def show_network_by_link_types(
         mnet: MultiNet,
         link_types: list,
@@ -222,6 +226,7 @@ def show_network_by_link_types(
 
     # draw network nodes
     extract_coordinates_by_link_types(mnet, link_types_)
+
     if mnet.node_loaded:
         ax.scatter(mnet.node.x_coords,
                    mnet.node.y_coords,
@@ -254,8 +259,9 @@ def show_network_by_link_types(
     plt.tight_layout()
 
     if isSave2png:
-        path_figure = update_filename(generate_absolute_path(file_name="network_by_link_type.png"))
-        plt.savefig(path_figure)
+        path_figure = update_filename(generate_absolute_path(file_name="network_by_link_type.png",
+                                                             folder_name=path2linux(os.path.join(os.getcwd(), "p4g_fig_results"))))
+        plt.savefig(path_figure,dpi=mnet.style.dpi)
         print(f"Successfully save figure to {path_figure}")
 
     return plt
@@ -331,14 +337,14 @@ def show_network_by_link_lanes(
     plt.tight_layout()
 
     if isSave2png:
-        path_figure = update_filename(generate_absolute_path(file_name="network_by_link_lane.png"))
-        plt.savefig(path_figure)
+        path_figure = update_filename(generate_absolute_path(file_name="network_by_link_lane.png",
+                                                             folder_name=path2linux(os.path.join(os.getcwd(), "p4g_fig_results"))))
+        plt.savefig(path_figure,dpi=mnet.style.dpi)
         print(f"Successfully save figure to {path_figure}")
 
     return plt
 
 
-
 def show_network_by_link_free_speed(
         mnet: MultiNet,
         min_free_speed: int,
@@ -410,8 +416,9 @@ def show_network_by_link_free_speed(
     plt.tight_layout()
 
     if isSave2png:
-        path_figure = update_filename(generate_absolute_path(file_name="network_by_link_free_speed.png"))
-        plt.savefig(path_figure)
+        path_figure = update_filename(generate_absolute_path(file_name="network_by_link_free_speed.png",
+                                                             folder_name=path2linux(os.path.join(os.getcwd(), "p4g_fig_results"))))
+        plt.savefig(path_figure,dpi=mnet.style.dpi)
         print(f"Successfully save figure to {path_figure}")
 
     return plt
@@ -486,8 +493,9 @@ def show_network_by_link_length(
     plt.tight_layout()
 
     if isSave2png:
-        path_figure = update_filename(generate_absolute_path(file_name="network_by_link_length.png"))
-        plt.savefig(path_figure)
+        path_figure = update_filename(generate_absolute_path(file_name="network_by_link_length.png",
+                                                             folder_name=path2linux(os.path.join(os.getcwd(), "p4g_fig_results"))))
+        plt.savefig(path_figure,dpi=mnet.style.dpi)
         print(f"Successfully save figure to {path_figure}")
 
     return plt
@@ -561,12 +569,14 @@ def show_network_by_link_lane_distribution(
     plt.tight_layout()
 
     if isSave2png:
-        path_figure = update_filename(generate_absolute_path(file_name="network_by_link_lane_distribution.png"))
-        plt.savefig(path_figure)
+        path_figure = update_filename(generate_absolute_path(file_name="network_by_link_lane_distribution.png",
+                                                             folder_name=path2linux(os.path.join(os.getcwd(), "p4g_fig_results"))))
+        plt.savefig(path_figure,dpi=mnet.style.dpi)
         print(f"Successfully save figure to {path_figure}")
 
     return plt
 
+
 def show_network_by_link_free_speed_distribution(
         mnet: MultiNet,
         fig_obj: plt = None,
@@ -635,12 +645,14 @@ def show_network_by_link_free_speed_distribution(
     plt.tight_layout()
 
     if isSave2png:
-        path_figure = update_filename(generate_absolute_path(file_name="network_by_link_free_speed_distribution.png"))
-        plt.savefig(path_figure)
+        path_figure = update_filename(generate_absolute_path(file_name="network_by_link_free_speed_distribution.png",
+                                                             folder_name=path2linux(os.path.join(os.getcwd(), "p4g_fig_results"))))
+        plt.savefig(path_figure,dpi=mnet.style.dpi)
         print(f"Successfully save figure to {path_figure}")
 
     return plt
 
+
 def show_network_by_link_capacity_distribution(
         mnet: MultiNet,
         fig_obj: plt = None,
@@ -708,8 +720,9 @@ def show_network_by_link_capacity_distribution(
     plt.tight_layout()
 
     if isSave2png:
-        path_figure = update_filename(generate_absolute_path(file_name="network_by_link_capacity_distribution.png"))
-        plt.savefig(path_figure)
+        path_figure = update_filename(generate_absolute_path(file_name="network_by_link_capacity_distribution.png",
+                                                             folder_name=path2linux(os.path.join(os.getcwd(), "p4g_fig_results"))))
+        plt.savefig(path_figure,dpi=mnet.style.dpi)
         print(f"Successfully save figure to {path_figure}")
 
     return plt
@@ -786,8 +799,9 @@ def show_network_by_poi_types(
     plt.tight_layout()
 
     if isSave2png:
-        path_figure = update_filename(generate_absolute_path(file_name="network_by_poi_type.png"))
-        plt.savefig(path_figure)
+        path_figure = update_filename(generate_absolute_path(file_name="network_by_poi_type.png",
+                                                             folder_name=path2linux(os.path.join(os.getcwd(), "p4g_fig_results"))))
+        plt.savefig(path_figure,dpi=mnet.style.dpi)
         print(f"Successfully save figure to {path_figure}")
 
     return plt
@@ -856,8 +870,9 @@ def show_network_by_poi_production_distribution(
     plt.tight_layout()
 
     if isSave2png:
-        path_figure = update_filename(generate_absolute_path(file_name="network_by_poi_production_distribution.png"))
-        plt.savefig(path_figure)
+        path_figure = update_filename(generate_absolute_path(file_name="network_by_poi_production_distribution.png",
+                                                             folder_name=path2linux(os.path.join(os.getcwd(), "p4g_fig_results"))))
+        plt.savefig(path_figure,dpi=mnet.style.dpi)
         print(f"Successfully save figure to {path_figure}")
 
     return plt
@@ -926,8 +941,9 @@ def show_network_by_poi_attraction_distribution(
     plt.tight_layout()
 
     if isSave2png:
-        path_figure = update_filename(generate_absolute_path(file_name="network_by_poi_attraction_distribution.png"))
-        plt.savefig(path_figure)
+        path_figure = update_filename(generate_absolute_path(file_name="network_by_poi_attraction_distribution.png",
+                                                             folder_name=path2linux(os.path.join(os.getcwd(), "p4g_fig_results"))))
+        plt.savefig(path_figure,dpi=mnet.style.dpi)
         print(f"Successfully save figure to {path_figure}")
 
     return plt
@@ -970,12 +986,14 @@ def show_network_demand_matrix_heatmap(
     plt.tight_layout()
 
     if isSave2png:
-        path_figure = update_filename(generate_absolute_path(file_name="network_by_demand_matrix_heatmap.png"))
-        plt.savefig(path_figure)
+        path_figure = update_filename(generate_absolute_path(file_name="network_by_demand_matrix_heatmap.png",
+                                                             folder_name=path2linux(os.path.join(os.getcwd(), "p4g_fig_results"))))
+        plt.savefig(path_figure,dpi=mnet.style.dpi)
         print(f"Successfully save figure to {path_figure}")
 
     return plt
 
+
 def show_network_by_demand_OD(
         mnet: MultiNet,
         load_zone: bool = True,
@@ -1069,8 +1087,9 @@ def show_network_by_demand_OD(
     plt.tight_layout()
 
     if isSave2png:
-        path_figure = update_filename(generate_absolute_path(file_name="network_by_demand_od.png"))
-        plt.savefig(path_figure)
+        path_figure = update_filename(generate_absolute_path(file_name="network_by_demand_od.png",
+                                                             folder_name=path2linux(os.path.join(os.getcwd(), "p4g_fig_results"))))
+        plt.savefig(path_figure,dpi=mnet.style.dpi)
         print(f"Successfully save figure to {path_figure}")
 
     return plt
